@@ -420,36 +420,35 @@ def colony(
         img_size = img.shape[:2]
         bk = img
     if by == "Species" or by == "species" or by == "type":
+        if fitness is True:
+            if not hasattr(obj, "colonies"):
+                obj.get_mothers()
+            fitness = obj.colonies
+            sorted = fitness[['mother_cell','total_biomass']].dropna().sort_values(by=['total_biomass']).reset_index(drop=True)
+            colors = dict()
+            IDs1 = df[['mother_cell','total_biomass']].dropna().sort_values(by=['total_biomass']).reset_index(drop=True).loc[df.type == 1].mother_cell.unique()
+            cya = colorFaderRGB("#01665e", "#c7eae5", len(IDs1))
 
-        colors = dict()
-        IDs1 = np.sort(df.loc[df.type == 1].mother_cell.unique())
-        cya = colorFaderRGB("#01665e", "#c7eae5", len(IDs1))
+            colors.update({i + 1: cya[i] for i, _ in enumerate(IDs1)})
+            IDs2 = df[['mother_cell','total_biomass']].dropna().sort_values(by=['total_biomass']).reset_index(drop=True).loc[df.type == 2].mother_cell.unique()
+            ecw = colorFaderRGB("#8c510a", "#f6e8c3", len(IDs2))
 
-        colors.update({i + 1: cya[i] for i, _ in enumerate(IDs1)})
-        IDs2 = np.sort(df.loc[df.type == 2].mother_cell.unique())
-        ecw = colorFaderRGB("#8c510a", "#f6e8c3", len(IDs2))
-
-        colors.update({i + len(IDs1) + 1: ecw[i] for i, _ in enumerate(IDs2)})
-        tp = df[df.Timestep == timepoint]
-        circles = [
-            cv2.circle(
-                bk,
-                center=(round(x * 1e6 * px_per_micron), round(y * 1e6 * px_per_micron)),
-                radius=round(radius * 1e6 * px_per_micron),
-                color=(
-                    int(colors[cell][0]),
-                    int(colors[cell][1]),
-                    int(colors[cell][2]),
-                ),
-                thickness=-1,
-            )
-            for x, y, radius, cell in zip(tp.x, tp.y, tp.radius, tp.mother_cell)
-        ]
-        if fitness is not None:
-            if fitness is True:
-                from nufeb_tools import spatial
-
-                fitness = spatial.fitness_metrics(obj)
+            colors.update({i + len(IDs1) + 1: ecw[i] for i, _ in enumerate(IDs2)})
+            tp = df[df.Timestep == timepoint]
+            circles = [
+                cv2.circle(
+                    bk,
+                    center=(round(x * 1e6 * px_per_micron), round(y * 1e6 * px_per_micron)),
+                    radius=round(radius * 1e6 * px_per_micron),
+                    color=(
+                        int(colors[cell][0]),
+                        int(colors[cell][1]),
+                        int(colors[cell][2]),
+                    ),
+                    thickness=-1,
+                )
+                for x, y, radius, cell in zip(tp.x, tp.y, tp.radius, tp.mother_cell)
+            ]
             if isinstance(fitness, pd.DataFrame):
                 # mark center of E. coli colonies
                 tp = df.loc[(df.Timestep == 0) & (df.type == 2)]
@@ -468,7 +467,7 @@ def colony(
                 ]
 
                 fit_list = (
-                    fitness.sort_values(by=["total biomass"], ascending=False)
+                    fitness.sort_values(by=["total_biomass"], ascending=False)
                     .loc[fitness.type == 2]
                     .reset_index(drop=True)["mother_cell"]
                     .to_numpy()
@@ -489,6 +488,31 @@ def colony(
                     )
                     for x, y, cell in zip(tp.x, tp.y, tp.mother_cell)
                 ]
+            else:
+                colors = dict()
+                IDs1 = np.sort(df.loc[df.type == 1].mother_cell.unique())
+                cya = colorFaderRGB("#01665e", "#c7eae5", len(IDs1))
+
+                colors.update({i + 1: cya[i] for i, _ in enumerate(IDs1)})
+                IDs2 = np.sort(df.loc[df.type == 2].mother_cell.unique())
+                ecw = colorFaderRGB("#8c510a", "#f6e8c3", len(IDs2))
+
+                colors.update({i + len(IDs1) + 1: ecw[i] for i, _ in enumerate(IDs2)})
+                tp = df[df.Timestep == timepoint]
+                circles = [
+                    cv2.circle(
+                        bk,
+                        center=(round(x * 1e6 * px_per_micron), round(y * 1e6 * px_per_micron)),
+                        radius=round(radius * 1e6 * px_per_micron),
+                        color=(
+                            int(colors[cell][0]),
+                            int(colors[cell][1]),
+                            int(colors[cell][2]),
+                        ),
+                        thickness=-1,
+                    )
+                    for x, y, radius, cell in zip(tp.x, tp.y, tp.radius, tp.mother_cell)
+                ]
     elif colony == None and by == None:
         if colors == None:
             IDs = np.sort(df[df.mother_cell != -1].mother_cell.unique())
